export function stop(event) {
    if (!event)
        return;
    event.stopImmediatePropagation();
    event.stopPropagation();
    event.preventDefault();
}
export class Event {
    constructor() {
        /**
         * Store all event this.data.
         */
        this.handlers = [];
    }
    on(events, handler, element, opts = {}) {
        if (typeof events === 'string') {
            events.split(' ').forEach(event => this.addEvent(event, element, handler, opts));
        }
        else {
            for (const event in events) {
                this.addEvent(event, handler, events[event], opts);
            }
        }
    }
    off(events, element) {
        if (typeof events === 'string') {
            events.split(' ').forEach(event => this.removeEvent(event, element));
        }
        else {
            for (const event in events) {
                this.removeEvent(event, element);
            }
        }
    }
    /**
     * Emit an event.
     * This method is only for custom events.
     *
     * @param event - An event name.
     * @param args  - Any number of arguments passed to handlers.
     */
    emit(event, ...args) {
        this.handlers.forEach(item => {
            if (!item.elm && item.event.split('.')[0] === event) {
                item.handler(...args);
            }
        });
    }
    /**
     * Clear event this.data.
     */
    destroy() {
        this.handlers.forEach(this.unroll);
        this.handlers = [];
    }
    /**
     * Remove the registered event listener.
     *
     * @param item - An object containing event this.data.
     */
    unroll(item) {
        item.elm && item.elm.removeEventListener(item.event, item.handler, item.opts);
    }
    addEvent(event, element, handler, opts) {
        element && element.addEventListener(event, handler, opts);
        this.handlers.push({ event, handler: handler, elm: element, opts: opts });
    }
    removeEvent(event, element) {
        this.handlers = this.handlers.filter(item => {
            if (item && item.event === event && item.elm === element) {
                this.unroll(item);
                return false;
            }
            return true;
        });
    }
}
//# sourceMappingURL=event.js.map