import { ComponentConstructor } from './components/component';
import { Slide } from './slide';
import { identity } from './types';
export declare type VirchualSettings = {
    slides?: string[] | (() => string[]);
    speed?: number;
    easing?: string;
    swipeDistanceThreshold?: number;
    flickVelocityThreshold?: number;
    flickPower?: number;
    pagination?: boolean;
    window?: number;
};
export declare class Virchual {
    container: HTMLElement;
    settings: VirchualSettings;
    frame: HTMLElement;
    currentIndex: number;
    slides: Slide[];
    private eventBus;
    private isBusy;
    private pagination;
    private eventBindings;
    constructor(container: HTMLElement, settings?: VirchualSettings);
    /**
     * Register component class.
     *
     * @param cls Component class.
     * @param settings Optional settings.
     */
    register<T, U>(cls: ComponentConstructor<T, U>, settings?: U): void;
    /**
     * Mount components.
     */
    mount(): void;
    /**
     * Disable Virchual instance and all user interactions (changing slides)
     *
     * @TODO
     */
    disable(): void;
    /**
     * Enable previously disabled Virchual instance. Enable user interaction.
     *
     * @TODO
     */
    enable(): void;
    /**
     * Register callback fired on the given event(s).
     *
     * @param events An event name. Use space to separate multiple events.
     *                             Also, namespace is accepted by dot, such as 'resize.{namespace}'.
     * @param handler A callback function.
     * @param elm  Optional. Native event will be listened to when this arg is provided.
     * @param opts Optional. Options for addEventListener.
     */
    on(events: string, handler: identity): void;
    /**
     * Unsubscribe the given event.
     *
     * @param events - A event name.
     * @param elm    - Optional. removeEventListener() will be called when this arg is provided.
     */
    off(events: string): void;
    /**
     * Go to previous slide.
     */
    prev(): void;
    /**
     * Go to next slide.
     */
    next(): void;
    /**
     * Destroy instance, remove DOM events.
     */
    destroy(): void;
    private goTo;
    private hydrate;
    /**
     * Mount and unmount slides.
     */
    private mountAndUnmountSlides;
    private bindEvents;
    /**
     * Called when frame is clicked.
     *
     * @param event A click event.
     */
    private onClick;
    /**
     * Handle drag event.
     *
     * @param event
     */
    private onDrag;
    /**
     * Handle dragged event.
     *
     * @param event
     */
    private onDragEnd;
}
