export declare function stop(event: MouseEvent | TouchEvent): void;
export declare class Event {
    /**
     * Store all event this.data.
     */
    private handlers;
    /**
     * Subscribe the given event(s).
     *
     * @param events  - An event name. Use space to separate multiple events.
     *                  Also, namespace is accepted by dot, such as 'resize.{namespace}'.
     * @param handler - A callback function.
     * @param element - Optional. Native event will be listened to when this arg is provided.
     * @param opts - Optional. Options for addEventListener.
     */
    on(events: string, handler: (...args: unknown[]) => void, element?: (Window & typeof globalThis) | Element, opts?: boolean | AddEventListenerOptions): void;
    /**
     * Unsubscribe the given event(s).
     *
     * @param events - A event name or names split by space.
     * @param element - Optional. removeEventListener() will be called when this arg is provided.
     */
    off(events: string, element?: (Window & typeof globalThis) | Element): void;
    /**
     * Emit an event.
     * This method is only for custom events.
     *
     * @param event - An event name.
     * @param args  - Any number of arguments passed to handlers.
     */
    emit(event: string, ...args: unknown[]): void;
    /**
     * Clear event this.data.
     */
    destroy(): void;
    /**
     * Remove the registered event listener.
     *
     * @param item - An object containing event this.data.
     */
    private unroll;
}
